﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.Windows.Data;
using System.Windows.Media.Effects;

namespace SilverlightApplication1
{
    public partial class MainPage : UserControl
    {
        ObservableCollection<TouchPoint> currentPoints = new ObservableCollection<TouchPoint>();
        TouchPoint primary = new TouchPoint();

        public MainPage()
        {
            InitializeComponent();
            Touch.FrameReported += new TouchFrameEventHandler(Touch_FrameReported);
            Loaded += new RoutedEventHandler(MainPage_Loaded);
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            PagedCollectionView data = new PagedCollectionView(currentPoints);
            data.GroupDescriptions.Add(new PropertyGroupDescription("Action"));
            TouchPointData.ItemsSource = data;
        }

        void Touch_FrameReported(object sender, TouchFrameEventArgs e)
        {

            foreach (TouchPoint tp in e.GetTouchPoints(Positions))
            {
                if (tp.Action == TouchAction.Down)
                {
                    currentPoints.Add(tp);
                    Ellipse pointLocation = new Ellipse();
                    pointLocation.Tag = tp.TouchDevice.Id;
                    pointLocation.Name = tp.TouchDevice.Id.ToString();
                    pointLocation.Width = 128;
                    pointLocation.Height = 128;
                    if ((e.GetPrimaryTouchPoint(Positions) != null))
                    {
                        if (e.GetPrimaryTouchPoint(Positions).Position != tp.Position)
                        {
                            pointLocation.Fill = new SolidColorBrush(Colors.White);
                        }
                        else
                        {
                            pointLocation.Fill = new SolidColorBrush(Colors.Red);
                        }
                    }
                    else
                    {
                        pointLocation.Fill = new SolidColorBrush(Colors.White);
                    }
                    
                    pointLocation.SetValue(Canvas.TopProperty, tp.Position.Y - 64);
                    pointLocation.SetValue(Canvas.LeftProperty, tp.Position.X - 64);
                    DropShadowEffect dse = new DropShadowEffect();
                    dse.BlurRadius = 100.0;
                    dse.Color = Colors.White;
                    dse.Direction = 0.0;
                    dse.ShadowDepth = 0.0;
                    pointLocation.Effect = dse;
                    Positions.Children.Add(pointLocation);
                }
                else if (tp.Action == TouchAction.Up)
                {
                    Positions.Children.Remove((UIElement)this.FindName(tp.TouchDevice.Id.ToString()));

                    var p = from pts in currentPoints
                            where pts.TouchDevice.Id == tp.TouchDevice.Id
                            select pts;

                    currentPoints.Remove(p.First());
                }
                else if (tp.Action == TouchAction.Move)
                {
                    Ellipse el = ((Ellipse)this.FindName(tp.TouchDevice.Id.ToString()));
                    el.SetValue(Canvas.TopProperty, tp.Position.Y - 64);
                    el.SetValue(Canvas.LeftProperty, tp.Position.X - 64);

                    var p = from pts in currentPoints
                            where pts.TouchDevice.Id == tp.TouchDevice.Id
                            select pts;

                    currentPoints.Remove(p.First());
                    currentPoints.Add(tp);
                }
            }
        }
    }
}